Common submodule
This module provides routines that are used throughout the library.
rainforest.common.io_data : read various MCH data formats
rainforest.common.retrieve_data : retrieve MCH files (COSMO, polar, Cartesian) from storage
rainforest.common.radarprocessing : radar processing routines
rainforest.common.constants : define constants used throughout the code
rainforest.common.graphics : creating plots for QPE realization and evaluation
rainforest.common.lookup : computing and reading lookup tables that are used for interpolation and geolocalization of data
rainforest.common.lookup : various small utilities used throughout the code