rainforest.ml package
This submodule deals with the training and evaluation of machine learning QPE methods. It also allows to read them from pickle files stored in the rf_models subfolder.
rainforest.ml.rf : main module used to train RF regressors
rainforest.ml.rfdefinitions : reference module that contains definitions of the RF regressors and allows to load them from files
rainforest.ml.rf_train : command-line utility to train RF models and prepare input features
rainforest.ml.utils : small utilities used in this module only (for example for vertical aggregation)